@@ -22,19 +22,21 @@ import (
 )
 
 type APTSystem struct {
-	CmdSet    map[string]*system.Command
-	Indicator system.Indicator
+	CmdSet            map[string]*system.Command
+	Indicator         system.Indicator
+	IncrementalUpdate bool
 }
 
-func NewSystem(nonUnknownList []string, otherList []string) system.System {
+func NewSystem(nonUnknownList []string, otherList []string, incrementalUpdate bool) system.System {
 	logger.Info("using apt for update...")
-	apt := New(nonUnknownList, otherList)
+	apt := New(nonUnknownList, otherList, incrementalUpdate)
 	return &apt
 }
 
-func New(nonUnknownList []string, otherList []string) APTSystem {
+func New(nonUnknownList []string, otherList []string, incrementalUpdate bool) APTSystem {
 	p := APTSystem{
-		CmdSet: make(map[string]*system.Command),
+		CmdSet:            make(map[string]*system.Command),
+		IncrementalUpdate: incrementalUpdate,
 	}
 	//WaitDpkgLockRelease()
 	//_ = exec.Command("/var/lib/lastore/scripts/build_safecache.sh").Run() // TODO
@@ -125,6 +127,11 @@ func WaitDpkgLockRelease() {
 	}
 }
 
+// ParsePkgSystemError is a wrapper for parsePkgSystemError
+func ParsePkgSystemError(out, err []byte) error {
+	return parsePkgSystemError(out, err)
+}
+
 func parsePkgSystemError(out, err []byte) error {
 	if len(err) == 0 {
 		return nil
@@ -267,6 +274,11 @@ func (p *APTSystem) DownloadSource(jobId string, packages []string, environ map[
 		}
 	*/
 
+	if p.IncrementalUpdate {
+		c := newAPTCommand(p, jobId, system.IncrementalDownloadJobType, p.Indicator, append(packages, OptionToArgs(args)...))
+		c.SetEnv(environ)
+		return c.Start()
+	}
 	c := newAPTCommand(p, jobId, system.PrepareDistUpgradeJobType, p.Indicator, append(packages, OptionToArgs(args)...))
 	c.SetEnv(environ)
 	return c.Start()
@@ -308,6 +320,14 @@ func (p *APTSystem) DistUpgrade(jobId string, packages []string, environ map[str
 			return err
 		}
 	}
+
+	if p.IncrementalUpdate {
+		logger.Info("incremental update")
+		c := newAPTCommand(p, jobId, system.IncrementalUpdateJobType, p.Indicator, append(packages, OptionToArgs(args)...))
+		c.SetEnv(environ)
+		return c.Start()
+	}
+
 	c := newAPTCommand(p, jobId, system.DistUpgradeJobType, p.Indicator, append(OptionToArgs(args), packages...))
 	environ["IMMUTABLE_DISABLE_REMOUNT"] = "false"
 	c.SetEnv(environ)
@@ -315,6 +335,12 @@ func (p *APTSystem) DistUpgrade(jobId string, packages []string, environ map[str
 }
 
 func (p *APTSystem) UpdateSource(jobId string, environ map[string]string, args map[string]string) error {
+	if p.IncrementalUpdate {
+		cmd := exec.Command(system.DeepinImmutableCtlPath, "upgrade", "update-remote")
+		if err := cmd.Run(); err != nil {
+			return err
+		}
+	}
 	c := newAPTCommand(p, jobId, system.UpdateSourceJobType, p.Indicator, OptionToArgs(args))
 	c.AtExitFn = func() bool {
 		// 无网络时检查更新失败,exitCode为0,空间不足(不确定exit code)导致需要特殊处理
@@ -537,8 +563,48 @@ func parseAptShowList(r io.Reader, title string) []string {
 	return p
 }
 
+// ImmutableCtlOutput is the json output of deepin-immutable-ctl command
+type ImmutableCtlOutput struct {
+	Code    uint8              `json:"code"`
+	Message string             `json:"message"`
+	Error   *ImmutableCtlError `json:"error"`
+	Data    interface{}        `json:"data"`
+}
+
+// ImmutableCtlError is the error of deepin-immutable-ctl command
+type ImmutableCtlError struct {
+	Code    string   `json:"code"`
+	Message []string `json:"message"`
+}
+
+func parseBackupJobError(stdErrStr string, stdOutStr string) *system.JobError {
+	var output ImmutableCtlOutput
+	err := json.Unmarshal([]byte(stdOutStr), &output)
+	if err != nil {
+		return &system.JobError{
+			ErrType:   system.ErrorUnknown,
+			ErrDetail: err.Error(),
+			ErrorLog:  []string{stdErrStr},
+		}
+	}
+	if output.Code == 0 {
+		// success
+		return nil
+	}
+
+	errDetail := fmt.Sprintf("err code: %v, err message: %+v",
+		output.Error.Code, output.Error.Message)
+
+	return &system.JobError{
+		ErrType:   system.ErrorUnknown,
+		ErrDetail: errDetail,
+		ErrorLog:  []string{stdErrStr},
+	}
+}
+
 func (p *APTSystem) OsBackup(jobId string) error {
-	c := newAPTCommand(p, jobId, system.BackupType, p.Indicator, nil)
+	c := newAPTCommand(p, jobId, system.BackupJobType, p.Indicator, nil)
+	c.ParseJobError = parseBackupJobError
 	c.ParseProgressInfo = func(id, line string) (system.JobProgressInfo, error) {
 		type info struct {
 			Progress    float64 `json:"progress"`
@@ -546,17 +612,15 @@ func (p *APTSystem) OsBackup(jobId string) error {
 		}
 
 		var progress float64
-		var status system.Status
 		var p info
 		if err := json.Unmarshal([]byte(line), &p); err == nil {
 			progress = p.Progress / 100.0
-			status = system.RunningStatus
 		}
 		return system.JobProgressInfo{
 			JobId:       jobId,
 			Progress:    progress,
 			Description: p.Description,
-			Status:      status,
+			Status:      system.RunningStatus,
 			Cancelable:  false,
 		}, nil
 	}
@@ -564,5 +628,11 @@ func (p *APTSystem) OsBackup(jobId string) error {
 		"IMMUTABLE_DISABLE_REMOUNT": "false",
 	}
 	c.SetEnv(environ)
+	c.Indicator(system.JobProgressInfo{
+		JobId:         jobId,
+		ResetProgress: true,
+		Status:        system.RunningStatus,
+		Cancelable:    false,
+	})
 	return c.Start()
 }
