@@ -7,7 +7,6 @@ package system
 import (
 	"bufio"
 	"encoding/json"
-	"github.com/linuxdeepin/go-lib/keyfile"
 	"io"
 	"os"
 	"os/exec"
@@ -19,9 +18,15 @@ import (
 	grub2 "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.grub2"
 	license "github.com/linuxdeepin/go-dbus-factory/system/com.deepin.license"
 	"github.com/linuxdeepin/go-lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/keyfile"
 	"github.com/linuxdeepin/go-lib/log"
 )
 
+const (
+	// DeepinImmutableCtlPath is the path of deepin-immutable-ctl
+	DeepinImmutableCtlPath = "/usr/sbin/deepin-immutable-ctl"
+)
+
 type MirrorSource struct {
 	Id   string `json:"id"`
 	Name string `json:"name"`
@@ -123,6 +128,22 @@ const (
 	ErrorScript        JobErrorType = "scriptError"
 	ErrorProgressCheck JobErrorType = "progressCheckError"
 
+	ErrorCheckMetaInfoFile       JobErrorType = "ErrorCheckMetaInfoFile"
+	ErrorPreCheckScriptsFailed   JobErrorType = "ErrorPreCheckScriptsFailed"
+	ErrorMidCheckScriptsFailed   JobErrorType = "ErrorMidCheckScriptsFailed"
+	ErrorPostCheckScriptsFailed  JobErrorType = "ErrorPostCheckScriptsFailed"
+	ErrorSysPkgInfoLoad          JobErrorType = "ErrorSysPkgInfoLoad"
+	ErrorCheckToolsDependFailed  JobErrorType = "ErrorCheckToolsDependFailed"
+	ErrorMetaInfoFile            JobErrorType = "ErrorMetaInfoFile"
+	ErrorDpkgVersion             JobErrorType = "ErrorDpkgVersion"
+	ErrorDpkgNotFound            JobErrorType = "ErrorDpkgNotFound"
+	ErrorCheckProgramFailed     JobErrorType = "ErrorCheckProgramFailed"
+	ErrorCheckSysDiskOutSpace    JobErrorType = "ErrorCheckSysDiskOutSpace"
+	ErrorCheckProcessNotRunning JobErrorType = "ErrorCheckProcessNotRunning"
+	ErrorCheckPkgNotFound        JobErrorType = "ErrorCheckPkgNotFound"
+	ErrorCheckPkgState           JobErrorType = "ErrorCheckPkgState"
+	ErrorCheckPkgVersion         JobErrorType = "ErrorCheckPkgVersion"
+
 	// running状态
 	ErrorNeedCheck JobErrorType = "needCheck"
 )
