@@ -6,11 +6,11 @@ package dut
 
 import (
 	"encoding/json"
+	"os"
+	"time"
+
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system/apt"
-	"os"
-	"sync"
-	"time"
 
 	"github.com/linuxdeepin/go-lib/utils"
 )
@@ -19,9 +19,9 @@ type DutSystem struct {
 	apt.APTSystem
 }
 
-func NewSystem(nonUnknownList []string, otherList []string) system.System {
+func NewSystem(nonUnknownList []string, otherList []string, incrementalUpdate bool) system.System {
 	logger.Info("using dut for update...")
-	aptImpl := apt.New(nonUnknownList, otherList)
+	aptImpl := apt.New(nonUnknownList, otherList, incrementalUpdate)
 	if !utils.IsFileExist(system.PlatFormSourceFile) {
 		file, err := os.Create(system.PlatFormSourceFile)
 		if err != nil {
@@ -68,10 +68,17 @@ func (p *DutSystem) OsBackup(jobId string) error {
 	return p.APTSystem.OsBackup(jobId)
 }
 
-func (p *DutSystem) CheckSystem(jobId string, checkType string, environ map[string]string, args map[string]string) error {
-	c := newDUTCommand(p, jobId, system.CheckSystemJobType, p.Indicator, OptionToArgs(args))
-	c.SetEnv(environ)
-	return c.Start()
+func (p *DutSystem) CheckSystem(jobId string, checkType string, environ map[string]string, options map[string]string) error {
+	// environ parameter is ignored here
+	fn := system.NewFunction(jobId, p.Indicator, func() error {
+		// only postCheck can be handled here, checkType is ignored
+		systemErr := CheckSystem(PostCheck, options)
+		if systemErr != nil {
+			return systemErr
+		}
+		return nil
+	})
+	return fn.Start()
 }
 
 func checkSystemDependsError(indicator system.Indicator) error {
@@ -80,29 +87,18 @@ func checkSystemDependsError(indicator system.Indicator) error {
 		logger.Warningf("apt-get check failed:%v", err)
 		return err
 	}
-	// 系统工具检查依赖目前还有问题，先不用系统工具检查
-	// cmd := exec.Command("deepin-system-fixpkg", "check")
-	// var outBuf bytes.Buffer
-	// cmd.Stdout = &outBuf
-	// var errBuf bytes.Buffer
-	// cmd.Stderr = &errBuf
-	// err = cmd.Run()
-	// if err == nil {
-	// 	return nil
-	// }
-	// return parsePkgSystemError(errBuf.String(), outBuf.String())
 	return nil
 }
 
-type checkType uint
+type CheckType uint
 
 const (
-	PreCheck  checkType = 0
-	MidCheck  checkType = 1
-	PostCheck checkType = 2
+	PreCheck  CheckType = 0
+	MidCheck  CheckType = 1
+	PostCheck CheckType = 2
 )
 
-func (t checkType) String() string {
+func (t CheckType) String() string {
 	switch t {
 	case PreCheck:
 		return "precheck"
@@ -114,13 +110,6 @@ func (t checkType) String() string {
 	return ""
 }
 
-type RuleInfo struct {
-	Name    string
-	Type    checkType
-	Command string
-	Argv    string
-}
-
 type RepoInfo struct {
 	Name       string
 	FilePath   string
@@ -129,12 +118,7 @@ type RepoInfo struct {
 
 type metaInfo struct {
 	PkgDebPath string
-	PkgList    []system.PackageInfo
 	CoreList   []system.PackageInfo
-	OptionList []system.PackageInfo
-	BaseLine   []system.PackageInfo
-	PurgeList  []system.PackageInfo
-	Rules      []RuleInfo
 	ReposInfo  []RepoInfo `json:"RepoInfo"`
 	UUID       string
 	Time       string
@@ -148,51 +132,15 @@ const (
 )
 
 // GenDutMetaFile metaPath为DutOnlineMetaConfPath或DutOfflineMetaConfPath
-func GenDutMetaFile(metaPath, debPath string, pkgMap, coreMap, optionMap, baseMap, removeMap map[string]system.PackageInfo, rules []RuleInfo, repoInfo []RepoInfo) (string, error) {
+func GenDutMetaFile(metaPath, debPath string,
+	coreMap map[string]system.PackageInfo, repoInfo []RepoInfo) (string, error) {
 	meta := metaInfo{
 		PkgDebPath: debPath,
 		UUID:       utils.GenUuid(),
 		Time:       time.Now().String(),
-		Rules:      rules,
 		ReposInfo:  repoInfo,
+		CoreList:   genPkgList(coreMap),
 	}
-	var pkgList []system.PackageInfo
-	var coreList []system.PackageInfo
-	var optionList []system.PackageInfo
-	var baseList []system.PackageInfo
-	var removeList []system.PackageInfo
-	var wg sync.WaitGroup
-	wg.Add(1)
-	go func() {
-		pkgList = genPkgList(pkgMap)
-		wg.Done()
-	}()
-	wg.Add(1)
-	go func() {
-		coreList = genCoreList(coreMap)
-		wg.Done()
-	}()
-	wg.Add(1)
-	go func() {
-		optionList = genOptionList(optionMap)
-		wg.Done()
-	}()
-	wg.Add(1)
-	go func() {
-		baseList = genBaseList(baseMap)
-		wg.Done()
-	}()
-	wg.Add(1)
-	go func() {
-		removeList = genRemoveList(removeMap)
-		wg.Done()
-	}()
-	wg.Wait()
-	meta.PkgList = pkgList
-	meta.CoreList = coreList
-	meta.OptionList = optionList
-	meta.BaseLine = baseList
-	meta.PurgeList = removeList
 	content, err := json.Marshal(meta)
 	if err != nil {
 		return "", err
@@ -216,52 +164,3 @@ func genPkgList(pkgMap map[string]system.PackageInfo) []system.PackageInfo {
 	}
 	return list
 }
-func genCoreList(pkgMap map[string]system.PackageInfo) []system.PackageInfo {
-	var list []system.PackageInfo
-	for _, v := range pkgMap {
-		info := system.PackageInfo{
-			Name:    v.Name,
-			Version: v.Version,
-			Need:    skipVersion,
-		}
-		list = append(list, info)
-	}
-	return list
-}
-func genOptionList(pkgMap map[string]system.PackageInfo) []system.PackageInfo {
-	var list []system.PackageInfo
-	for _, v := range pkgMap {
-		info := system.PackageInfo{
-			Name:    v.Name,
-			Version: v.Version,
-			Need:    exist,
-		}
-		list = append(list, info)
-	}
-	return list
-}
-func genBaseList(pkgMap map[string]system.PackageInfo) []system.PackageInfo {
-	var list []system.PackageInfo
-	for _, v := range pkgMap {
-		info := system.PackageInfo{
-			Name:    v.Name,
-			Version: v.Version,
-			Need:    skipVersion,
-		}
-		list = append(list, info)
-	}
-	return list
-}
-
-func genRemoveList(removeMap map[string]system.PackageInfo) []system.PackageInfo {
-	var list []system.PackageInfo
-	for _, v := range removeMap {
-		info := system.PackageInfo{
-			Name:    v.Name,
-			Version: v.Version,
-			Need:    exist,
-		}
-		list = append(list, info)
-	}
-	return list
-}
