@@ -26,6 +26,7 @@ import (
 	"time"
 
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system/dut"
+	"github.com/linuxdeepin/lastore-daemon/src/lastore-update-tools/controller/check"
 
 	"github.com/godbus/dbus/v5"
 	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
@@ -39,6 +40,19 @@ import (
 
 var logger = log.NewLogger("lastore/messageReport")
 
+type ShellCheck struct {
+	Name  string `json:"name"`  //检查脚本的名字
+	Shell string `json:"shell"` //检查脚本的内容
+}
+
+// 发送给更新平台的状态信息
+type StatusMessage struct {
+	Type           string `json:"type"`           //消息类型，info,warning,error
+	UpdateType     string `json:"updateType"`     //system.UpdateType类型
+	JobDescription string `json:"jobDescription"` //job.Description
+	Detail         string `json:"detail"`         //消息详情
+}
+
 type UpdatePlatformManager struct {
 	config                            *Config
 	allowPostSystemUpgradeMessageType system.UpdateType
@@ -51,9 +65,9 @@ type UpdatePlatformManager struct {
 	systemTypeFromPlatform string // 从更新平台获取的系统类型,本地os-baseline.b获取
 	requestUrl             string // 更新平台请求地址
 
-	PreCheck       string                        // 更新前检查脚本
-	MidCheck       string                        // 更新中检查脚本
-	PostCheck      string                        // 更新后检查脚本
+	PreCheck       []ShellCheck                  // 更新前检查脚本
+	MidCheck       []ShellCheck                  // 更新后检查脚本
+	PostCheck      []ShellCheck                  // 更新完成重启后检查脚本
 	TargetCorePkgs map[string]system.PackageInfo // 必须安装软件包信息清单  	对应dut的core list
 	BaselinePkgs   map[string]system.PackageInfo // 当前版本的核心软件包清单	对应dut的baseline
 	SelectPkgs     map[string]system.PackageInfo // 可选软件包清单
@@ -85,9 +99,9 @@ type platformCacheContent struct {
 	CoreListPkgs map[string]system.PackageInfo
 	BaselinePkgs map[string]system.PackageInfo
 	SelectPkgs   map[string]system.PackageInfo
-	PreCheck     string
-	MidCheck     string
-	PostCheck    string
+	PreCheck     []ShellCheck
+	MidCheck     []ShellCheck
+	PostCheck    []ShellCheck
 }
 
 // 需要注意cache文件的同步时机，所有数据应该不会从os-version和os-baseline获取
@@ -468,6 +482,7 @@ func (m *UpdatePlatformManager) genTargetPkgListsResponse() (*http.Response, err
 	values := url.Values{}
 	values.Add("baseline", m.targetBaseline)
 	policyUrl = policyUrl + "?" + values.Encode()
+
 	request, err := http.NewRequest(Urls[GetTargetPkgLists].method, policyUrl, nil)
 	if err != nil {
 		return nil, fmt.Errorf("%v new request failed: %v ", GetTargetPkgLists.string(), err.Error())
@@ -767,9 +782,9 @@ type packageLists struct {
 }
 
 type PreInstalledPkgMeta struct {
-	PreCheck  string       `json:"preCheck"`  // "更新前检查脚本"
-	MidCheck  string       `json:"midCheck"`  // "更新中检查"
-	PostCheck string       `json:"postCheck"` // "更新后检查"
+	PreCheck  []ShellCheck `json:"preCheck"`  // "更新前检查脚本"
+	MidCheck  []ShellCheck `json:"midCheck"`  // "更新后检查脚本"
+	PostCheck []ShellCheck `json:"postCheck"` // "更新完成重启后检查脚本"
 	Packages  packageLists `json:"packages"`  // "基线软件包清单"
 }
 
@@ -1309,12 +1324,20 @@ func (m *UpdatePlatformManager) UpdateAllPlatformDataSync() error {
 }
 
 // PostStatusMessage 将检查\下载\安装过程中所有异常状态和每个阶段成功的正常状态上报
-func (m *UpdatePlatformManager) PostStatusMessage(body string) {
-	logger.Debug("post status msg:", body)
+func (m *UpdatePlatformManager) PostStatusMessage(message StatusMessage) {
 	if (m.config.PlatformDisabled & DisabledProcess) != 0 {
 		return
 	}
-	buf := bytes.NewBufferString(body)
+
+	msg, err := json.Marshal(message)
+	if err != nil {
+		logger.Warningf("marshal status message failed:%v", err)
+		return
+	}
+
+	logger.Debugf("post status msg:%s", msg)
+
+	buf := bytes.NewBufferString(string(msg))
 	filePath := fmt.Sprintf("/tmp/%s_%s.xz", "update", time.Now().Format("20231019102233444"))
 	response, err := m.genPostProcessResponse(buf, filePath)
 	if err != nil {
@@ -1509,8 +1532,6 @@ func (m *UpdatePlatformManager) PostSystemUpgradeMessage(uuid string) {
 }
 
 func (m *UpdatePlatformManager) RetryPostHistory() {
-	m.jobPostMsgMapMu.Lock()
-	defer m.jobPostMsgMapMu.Unlock()
 	for _, v := range m.jobPostMsgMap {
 		if v.PostStatus == WaitPost || v.PostStatus == PostFailure {
 			m.PostSystemUpgradeMessage(v.Uuid)
@@ -1519,58 +1540,76 @@ func (m *UpdatePlatformManager) RetryPostHistory() {
 	return
 }
 
-func (m *UpdatePlatformManager) GetRules() []dut.RuleInfo {
-	defaultCmd := "echo default rules"
-	var rules []dut.RuleInfo
+// PrepareCheckScripts decodes and deploys base64-encoded check scripts to the filesystem.
+// It processes three types of check scripts:
+//   - PreCheck: scripts executed before system update
+//   - MidCheck: scripts executed during system update
+//   - PostCheck: scripts executed after system update
+//
+// The function performs the following operations:
+//  1. Cleans up existing script directories
+//  2. Creates fresh directories for each check type
+//  3. Decodes base64-encoded script content from memory
+//  4. Writes executable script files to the filesystem with 0755 permissions
+//
+// Script files are organized under /var/lib/lastore/check/ in subdirectories:
+//   - pre_check/: for pre-update validation scripts
+//   - mid_check/: for mid-update validation scripts
+//   - post_check/: for post-update validation scripts
+//
+// Any decode or file write errors are logged as warnings but do not stop
+// the processing of remaining scripts.
+func (m *UpdatePlatformManager) PrepareCheckScripts() {
 
-	if len(strings.TrimSpace(m.PreCheck)) == 0 {
-		rules = append(rules, dut.RuleInfo{
-			Name:    "00_precheck",
-			Type:    dut.PreCheck,
-			Command: defaultCmd,
-			Argv:    "",
-		})
-	} else {
-		rules = append(rules, dut.RuleInfo{
-			Name:    "00_precheck",
-			Type:    dut.PreCheck,
-			Command: m.PreCheck,
-			Argv:    "",
-		})
+	preShellPath := filepath.Join(check.CheckBaseDir, "pre_check")
+	midShellPath := filepath.Join(check.CheckBaseDir, "mid_check")
+	postShellPath := filepath.Join(check.CheckBaseDir, "post_check")
+
+	_ = os.RemoveAll(preShellPath)
+	_ = os.RemoveAll(midShellPath)
+	_ = os.RemoveAll(postShellPath)
+
+	err := utils.EnsureDirExist(preShellPath)
+	if err != nil {
+		logger.Warning(err)
 	}
 
-	if len(strings.TrimSpace(m.MidCheck)) == 0 {
-		rules = append(rules, dut.RuleInfo{
-			Name:    "10_midcheck",
-			Type:    dut.MidCheck,
-			Command: defaultCmd,
-			Argv:    "",
-		})
-	} else {
-		rules = append(rules, dut.RuleInfo{
-			Name:    "10_midcheck",
-			Type:    dut.MidCheck,
-			Command: m.MidCheck,
-			Argv:    "",
-		})
+	err = utils.EnsureDirExist(midShellPath)
+	if err != nil {
+		logger.Warning(err)
 	}
 
-	if len(strings.TrimSpace(m.PostCheck)) == 0 {
-		rules = append(rules, dut.RuleInfo{
-			Name:    "20_postcheck",
-			Type:    dut.PostCheck,
-			Command: defaultCmd,
-			Argv:    "",
-		})
-	} else {
-		rules = append(rules, dut.RuleInfo{
-			Name:    "20_postcheck",
-			Type:    dut.PostCheck,
-			Command: m.PostCheck,
-			Argv:    "",
-		})
+	err = utils.EnsureDirExist(postShellPath)
+	if err != nil {
+		logger.Warning(err)
+	}
+
+	checkGroups := []struct {
+		list      []ShellCheck
+		dir       string
+		checkType dut.CheckType
+	}{
+		{m.PreCheck, preShellPath, dut.PreCheck},
+		{m.MidCheck, midShellPath, dut.MidCheck},
+		{m.PostCheck, postShellPath, dut.PostCheck},
+	}
+
+	for _, g := range checkGroups {
+		for _, c := range g.list {
+			filePath := filepath.Join(g.dir, c.Name)
+			content, err := base64.RawStdEncoding.DecodeString(c.Shell)
+			if err != nil {
+				logger.Warningf("decode shell for %s failed: %v", c.Name, err)
+				continue
+			}
+
+			if err := utils.SyncWriteFile(filePath, content, 0755); err != nil {
+				logger.Warningf("write file %s failed: %v", filePath, err)
+				continue
+			}
+
+		}
 	}
-	return rules
 }
 
 func (m *UpdatePlatformManager) SaveCache(c *Config) {
