@@ -21,7 +21,7 @@ import (
 	"github.com/linuxdeepin/go-lib/gettext"
 )
 
-func (m *Manager) prepareDistUpgrade(sender dbus.Sender, origin system.UpdateType) (*Job, error) {
+func (m *Manager) prepareDistUpgrade(sender dbus.Sender, origin system.UpdateType, initiator Initiator) (*Job, error) {
 	if m.ImmutableAutoRecovery {
 		logger.Info("immutable auto recovery is enabled, don't allow to exec prepareDistUpgrade")
 		return nil, errors.New("immutable auto recovery is enabled, don't allow to exec prepareDistUpgrade")
@@ -112,6 +112,7 @@ func (m *Manager) prepareDistUpgrade(sender dbus.Sender, origin system.UpdateTyp
 	if isExist {
 		return job, nil
 	}
+	job.initiator = initiator
 	currentJob := job
 	var sendDownloadingOnce sync.Once
 	// 遍历job和所有next
@@ -186,7 +187,13 @@ func (m *Manager) prepareDistUpgrade(sender dbus.Sender, origin system.UpdateTyp
 					m.inhibitAutoQuitCountAdd()
 					defer m.inhibitAutoQuitCountSub()
 					m.reportLog(downloadStatusReport, false, j.Description)
-					m.updatePlatform.PostStatusMessage(fmt.Sprintf("download %v package failed, detail is %v", mode.JobType(), job.Description)) // 上报下载失败状态
+					// 上报下载失败状态
+					m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+						Type:           "error",
+						UpdateType:     mode.JobType(),
+						JobDescription: job.Description,
+						Detail:         fmt.Sprintf("download %v package failed, detail is %v", mode.JobType(), job.Description),
+					})
 				}()
 				return nil
 			},
@@ -219,7 +226,14 @@ func (m *Manager) prepareDistUpgrade(sender dbus.Sender, origin system.UpdateTyp
 						m.inhibitAutoQuitCountSub()
 					}
 				}
-				m.updatePlatform.PostStatusMessage(fmt.Sprintf("download %v package success", j.updateTyp.JobType())) // 上报下载成功状态
+
+				// 上报下载成功状态
+				m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+					Type:           "info",
+					UpdateType:     j.updateTyp.JobType(),
+					JobDescription: j.Description,
+					Detail:         fmt.Sprintf("download %v package success", j.updateTyp.JobType()),
+				})
 				return nil
 			},
 			string(system.EndStatus): func() error {
