@@ -26,6 +26,7 @@ import (
 	utils2 "github.com/linuxdeepin/go-lib/utils"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/config"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system/apt"
 )
 
 /*
@@ -93,9 +94,13 @@ func (m *Manager) InstallPackage(sender dbus.Sender, jobName string, packages st
 	}
 	if !allowInstallPackageExecPaths.Contains(execPath) &&
 		uid != 0 {
-		err = fmt.Errorf("%q is not allowed to install packages", execPath)
-		logger.Warning(err)
-		return "/", dbusutil.ToError(err)
+		// 白名单未通过时需要管理员鉴权
+		err = polkit.CheckAuth(polkitActionChangeOwnData, string(sender), nil)
+		if err != nil {
+			err = fmt.Errorf("%q is not in allowed install package paths.And the caller not pass the authentication, don't allow to install packages %v", execPath, packages)
+			logger.Warning(err)
+			return "/", dbusutil.ToError(err)
+		}
 	}
 
 	jobObj, err := m.installPackage(sender, jobName, packages)
@@ -209,6 +214,10 @@ func (m *Manager) PackagesDownloadSize(packages []string) (int64, *dbus.Error) {
 		logger.Warningf("PackagesDownloadSize(%q)=%0.2f %v\n", strings.Join(packages, " "), size, err)
 	}
 
+	if m.config.IncrementalUpdate && size > 0 && apt.IsIncrementalUpdateCached() {
+		size = 0.0
+	}
+
 	return int64(size), dbusutil.ToError(err)
 }
 
@@ -486,7 +495,7 @@ func (m *Manager) QueryAllSizeWithSource(mode system.UpdateType) (int64, *dbus.E
 
 func (m *Manager) PrepareDistUpgradePartly(sender dbus.Sender, mode system.UpdateType) (job dbus.ObjectPath, busErr *dbus.Error) {
 	m.service.DelayAutoQuit()
-	jobObj, err := m.prepareDistUpgrade(sender, mode)
+	jobObj, err := m.prepareDistUpgrade(sender, mode, initiatorUser)
 	if err != nil {
 		logger.Warning(err)
 		return "/", dbusutil.ToError(err)
